/// <reference types="graphql" />
import { DocumentNode } from 'graphql';
import { ApolloStore, Store } from '../store';
import { DataWrite } from '../actions';
import { IdGetter } from '../core/types';
import { NormalizedCache } from '../data/storeUtils';
export interface DataProxy {
    readQuery<QueryType>(config: {
        query: DocumentNode;
        variables?: Object;
    }): QueryType;
    readFragment<FragmentType>(config: {
        id: string;
        fragment: DocumentNode;
        fragmentName?: string;
        variables?: Object;
    }): FragmentType | null;
    writeQuery(config: {
        data: any;
        query: DocumentNode;
        variables?: Object;
    }): void;
    writeFragment(config: {
        data: any;
        id: string;
        fragment: DocumentNode;
        fragmentName?: string;
        variables?: Object;
    }): void;
}
export declare class ReduxDataProxy implements DataProxy {
    private store;
    private reduxRootSelector;
    constructor(store: ApolloStore, reduxRootSelector: (state: any) => Store);
    readQuery<QueryType>({query, variables}: {
        query: DocumentNode;
        variables?: Object;
    }): QueryType;
    readFragment<FragmentType>({id, fragment, fragmentName, variables}: {
        id: string;
        fragment: DocumentNode;
        fragmentName?: string;
        variables?: Object;
    }): FragmentType | null;
    writeQuery({data, query, variables}: {
        data: any;
        query: DocumentNode;
        variables?: Object;
    }): void;
    writeFragment({data, id, fragment, fragmentName, variables}: {
        data: any;
        id: string;
        fragment: DocumentNode;
        fragmentName?: string;
        variables?: Object;
    }): void;
}
export declare class TransactionDataProxy implements DataProxy {
    private data;
    private dataIdFromObject;
    private writes;
    private isFinished;
    constructor(data: NormalizedCache, dataIdFromObject?: IdGetter);
    finish(): Array<DataWrite>;
    readQuery<QueryType>({query, variables}: {
        query: DocumentNode;
        variables?: Object;
    }): QueryType;
    readFragment<FragmentType>({id, fragment, fragmentName, variables}: {
        id: string;
        fragment: DocumentNode;
        fragmentName?: string;
        variables?: Object;
    }): FragmentType | null;
    writeQuery({data, query, variables}: {
        data: any;
        query: DocumentNode;
        variables?: Object;
    }): void;
    writeFragment({data, id, fragment, fragmentName, variables}: {
        data: any;
        id: string;
        fragment: DocumentNode;
        fragmentName?: string;
        variables?: Object;
    }): void;
    private assertNotFinished();
    private applyWrite(write);
}
